@@ -191,7 +191,7 @@ void MainWindow::about()
   t << QString::fromAscii("<qt><center>A tool to configure and run doxygen version ")+
        QString::fromAscii(versionString)+
        QString::fromAscii(" on your source files.</center><p><br>"
-       "<center>Written by<br> Dimitri van Heesch<br>&copy; 2000-2010</center><p>"
+       "<center>Written by<br> Dimitri van Heesch<br>&copy; 2000-2013</center><p>"
        "</qt>");
   QMessageBox::about(this,tr("Doxygen GUI"),msg);
 }
@@ -483,7 +483,7 @@ void MainWindow::readStdout()
   if (m_running)
   {
     QByteArray data = m_runProcess->readAllStandardOutput();
-    QString text = QString::fromLocal8Bit(data);
+    QString text = QString::fromUtf8(data);
     if (!text.isEmpty())
     {
       m_outputLog->append(text.trimmed());
@@ -525,7 +525,7 @@ void MainWindow::showHtmlOutput()
   // TODO: the following doesn't seem to work with IE
 #ifdef WIN32
   //QString indexUrl(QString::fromAscii("file:///"));
-  ShellExecute(NULL, L"open", fi.absoluteFilePath().utf16(), NULL, NULL, SW_SHOWNORMAL);
+  ShellExecute(NULL, L"open", (LPCWSTR)fi.absoluteFilePath().utf16(), NULL, NULL, SW_SHOWNORMAL);
 #else
   QString indexUrl(QString::fromAscii("file://"));
   indexUrl+=fi.absoluteFilePath();
