@@ -3,7 +3,7 @@
  * 
  *
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -113,6 +113,7 @@ CommandMap cmdMap[] =
   { "$",             CMD_DOLLAR },
   { "#",             CMD_HASH },
   { "%",             CMD_PERCENT },
+  { "|",             CMD_PIPE },
   { "::",            CMD_DCOLON },
   { "\"",            CMD_QUOTE },
   { "_internalref",  CMD_INTERNALREF },
@@ -127,6 +128,10 @@ CommandMap cmdMap[] =
   { "mscfile",       CMD_MSCFILE },
   { "rtfonly",       CMD_RTFONLY },
   { "endrtfonly",    CMD_ENDRTFONLY },
+  { "vhdlflow",      CMD_VHDLFLOW },
+  { "docbookonly",   CMD_DBONLY },
+  { "enddocbookonly",CMD_ENDDBONLY },
+  { "endinternal",   CMD_ENDINTERNAL },
   { 0,               0 },
 };
 
