@@ -40,6 +40,9 @@
 "    <xsd:attribute name=\"id\" type=\"xsd:string\" />\n"
 "    <xsd:attribute name=\"kind\" type=\"DoxCompoundKind\" />\n"
 "    <xsd:attribute name=\"prot\" type=\"DoxProtectionKind\" />\n"
+"    <xsd:attribute name=\"final\" type=\"DoxBool\" use=\"optional\"/>\n"
+"    <xsd:attribute name=\"sealed\" type=\"DoxBool\" use=\"optional\"/>\n"
+"    <xsd:attribute name=\"abstract\" type=\"DoxBool\" use=\"optional\"/>\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"listofallmembersType\">\n"
@@ -169,6 +172,18 @@
 "    <xsd:attribute name=\"required\" type=\"DoxBool\" use=\"optional\"/>\n"
 "    <!-- Objective-C 2.0 property accessor -->\n"
 "    <xsd:attribute name=\"accessor\" type=\"DoxAccessor\" use=\"optional\"/>\n"
+"    <!-- UNO IDL -->\n"
+"    <xsd:attribute name=\"attribute\" type=\"DoxBool\" use=\"optional\"/>\n"
+"    <xsd:attribute name=\"property\" type=\"DoxBool\" use=\"optional\"/>\n"
+"    <xsd:attribute name=\"readonly\" type=\"DoxBool\" use=\"optional\"/>\n"
+"    <xsd:attribute name=\"bound\" type=\"DoxBool\" use=\"optional\"/>\n"
+"    <xsd:attribute name=\"removable\" type=\"DoxBool\" use=\"optional\"/>\n"
+"    <xsd:attribute name=\"contrained\" type=\"DoxBool\" use=\"optional\"/>\n"
+"    <xsd:attribute name=\"transient\" type=\"DoxBool\" use=\"optional\"/>\n"
+"    <xsd:attribute name=\"maybevoid\" type=\"DoxBool\" use=\"optional\"/>\n"
+"    <xsd:attribute name=\"maybedefault\" type=\"DoxBool\" use=\"optional\"/>\n"
+"    <xsd:attribute name=\"maybeambiguous\" type=\"DoxBool\" use=\"optional\"/>\n"
+"\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"descriptionType\" mixed=\"true\">\n"
@@ -276,6 +291,7 @@
 "  <xsd:complexType name=\"locationType\">\n"
 "    <xsd:attribute name=\"file\" type=\"xsd:string\" />\n"
 "    <xsd:attribute name=\"line\" type=\"xsd:integer\" />\n"
+"    <xsd:attribute name=\"column\" type=\"xsd:integer\" use=\"optional\"/>\n"
 "    <xsd:attribute name=\"bodyfile\" type=\"xsd:string\" />\n"
 "    <xsd:attribute name=\"bodystart\" type=\"xsd:integer\" />\n"
 "    <xsd:attribute name=\"bodyend\" type=\"xsd:integer\" />\n"
@@ -392,6 +408,75 @@
 "      <xsd:element name=\"ring\" type=\"docCharType\" />\n"
 "      <xsd:element name=\"szlig\" type=\"docEmptyType\" />\n"
 "      <xsd:element name=\"nonbreakablespace\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"aelig\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"AElig\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Gamma\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Delta\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Theta\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Lambda\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Xi\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Pi\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Sigma\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Upsilon\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Phi\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Psi\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Omega\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"alpha\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"beta\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"gamma\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"delta\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"epsilon\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"zeta\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"eta\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"theta\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"iota\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"kappa\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"lambda\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"mu\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"nu\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"xi\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"pi\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"rho\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"sigma\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"tau\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"upsilon\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"phi\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"chi\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"psi\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"omega\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"sigmaf\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"sect\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"deg\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"prime\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Prime\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"infin\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"empty\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"plusmn\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"times\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"minus\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"sdot\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"part\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"nabla\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"radic\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"perp\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"sum\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"int\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"prod\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"sim\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"asymp\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"ne\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"equiv\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"prop\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"le\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"ge\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"larr\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"rarr\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"isin\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"notin\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"lceil\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"rceil\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"lfloor\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"rfloor\" type=\"docEmptyType\" />\n"
 "    </xsd:choice>\n"
 "  </xsd:group>\n"
 "\n"
@@ -669,6 +754,8 @@
 "      <xsd:enumeration value=\"friend\" />\n"
 "      <xsd:enumeration value=\"dcop\" />\n"
 "      <xsd:enumeration value=\"slot\" />\n"
+"      <xsd:enumeration value=\"interface\" />\n"
+"      <xsd:enumeration value=\"service\" />\n"
 "    </xsd:restriction>\n"
 "  </xsd:simpleType>\n"
 "\n"
@@ -698,6 +785,10 @@
 "      <xsd:enumeration value=\"protocol\" />\n"
 "      <xsd:enumeration value=\"category\" />\n"
 "      <xsd:enumeration value=\"exception\" />\n"
+"      <xsd:enumeration value=\"service\" />\n"
+"      <xsd:enumeration value=\"singleton\" />\n"
+"      <xsd:enumeration value=\"module\" />\n"
+"      <xsd:enumeration value=\"type\" />\n"
 "      <xsd:enumeration value=\"file\" />\n"
 "      <xsd:enumeration value=\"namespace\" />\n"
 "      <xsd:enumeration value=\"group\" />\n"
@@ -827,6 +918,7 @@
 "      <xsd:enumeration value=\"assign\"/>\n"
 "      <xsd:enumeration value=\"weak\"/>\n"
 "      <xsd:enumeration value=\"strong\"/>\n"
+"      <xsd:enumeration value=\"unretained\"/>\n"
 "    </xsd:restriction>\n"
 "  </xsd:simpleType>\n"
 "\n"
