@@ -1,9 +1,9 @@
 /******************************************************************************
  *
- * $Id: config.h,v 1.39 2001/03/19 19:27:40 root Exp $
+ * 
  *
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -19,9 +19,7 @@
 #ifndef CONFIG_H
 #define CONFIG_H
 
-#include "qtbc.h"
 #include <qstrlist.h>
-#include <qfile.h>
 #include <qdict.h>
 #include <qlist.h>
 #include "ftextstream.h"
@@ -44,7 +42,8 @@ class ConfigOption
       O_String,    //<! A single item
       O_Int,       //<! An integer value
       O_Bool,      //<! A boolean value
-      O_Obsolete   //<! An obsolete option
+      O_Obsolete,  //<! An obsolete option
+      O_Disabled   //<! Disabled compile time option
     };
     enum 
     { 
@@ -69,15 +68,14 @@ class ConfigOption
     QCString dependsOn() const { return m_dependency; }
     void addDependency(const char *dep) { m_dependency = dep; }
     void setEncoding(const QCString &e) { m_encoding = e; }
+    void setUserComment(const QCString &u) { m_userComment = u; }
 
   protected:
     virtual void writeTemplate(FTextStream &t,bool sl,bool upd) = 0;
     virtual void convertStrToVal() {}
     virtual void substEnvVars() = 0;
-    virtual void writeXML(FTextStream&) {}
     virtual void init() {}
 
-    QCString convertToComment(const QCString &s);
     void writeBoolValue(FTextStream &t,bool v);
     void writeIntValue(FTextStream &t,int i);
     void writeStringValue(FTextStream &t,QCString &s);
@@ -88,6 +86,7 @@ class ConfigOption
     QCString m_doc;
     QCString m_dependency;
     QCString m_encoding;
+    QCString m_userComment;
     OptionType m_kind;
 };
 
@@ -102,16 +101,7 @@ class ConfigInfo : public ConfigOption
       m_name = name;
       m_doc = doc;
     }
-    void writeTemplate(FTextStream &t, bool sl,bool)
-    {
-      if (!sl)
-      {
-        t << "\n";
-      }
-      t << "#---------------------------------------------------------------------------\n";
-      t << "# " << m_doc << endl;
-      t << "#---------------------------------------------------------------------------\n";
-    }
+    void writeTemplate(FTextStream &t, bool sl,bool);
     void substEnvVars() {}
 };
 
@@ -132,20 +122,8 @@ class ConfigList : public ConfigOption
     void setWidgetType(WidgetType w) { m_widgetType = w; }
     WidgetType widgetType() const { return m_widgetType; }
     QStrList *valueRef() { return &m_value; }
-    void writeTemplate(FTextStream &t,bool sl,bool)
-    {
-      if (!sl)
-      {
-        t << endl;
-        t << convertToComment(m_doc);
-        t << endl;
-      }
-      t << m_name << m_spaces.left(MAX_OPTION_LENGTH-m_name.length()) << "=";
-      writeStringList(t,m_value);
-      t << "\n";
-    }
+    void writeTemplate(FTextStream &t,bool sl,bool);
     void substEnvVars();
-    void writeXML(FTextStream&);
     void init() { m_value.clear(); }
   private:
     QStrList m_value;
@@ -172,19 +150,7 @@ class ConfigEnum : public ConfigOption
     }
     QCString *valueRef() { return &m_value; }
     void substEnvVars();
-    void writeTemplate(FTextStream &t,bool sl,bool)
-    {
-      if (!sl)
-      {
-        t << endl;
-        t << convertToComment(m_doc);
-        t << endl;
-      }
-      t << m_name << m_spaces.left(MAX_OPTION_LENGTH-m_name.length()) << "=";
-      writeStringValue(t,m_value);
-      t << "\n";
-    }
-    void writeXML(FTextStream&);
+    void writeTemplate(FTextStream &t,bool sl,bool);
     void init() { m_value = m_defValue.copy(); }
 
   private:
@@ -213,20 +179,8 @@ class ConfigString : public ConfigOption
     WidgetType widgetType() const { return m_widgetType; }
     void setDefaultValue(const char *v) { m_defValue = v; }
     QCString *valueRef() { return &m_value; }
-    void writeTemplate(FTextStream &t,bool sl,bool)
-    {
-      if (!sl)
-      {
-        t << endl;
-        t << convertToComment(m_doc);
-        t << endl;
-      }
-      t << m_name << m_spaces.left(MAX_OPTION_LENGTH-m_name.length()) << "=";
-      writeStringValue(t,m_value);
-      t << "\n";
-    }
+    void writeTemplate(FTextStream &t,bool sl,bool);
     void substEnvVars();
-    void writeXML(FTextStream&);
     void init() { m_value = m_defValue.copy(); }
   
   private:
@@ -256,26 +210,7 @@ class ConfigInt : public ConfigOption
     int maxVal() const { return m_maxVal; }
     void convertStrToVal();
     void substEnvVars();
-    void writeTemplate(FTextStream &t,bool sl,bool upd)
-    {
-      if (!sl)
-      {
-        t << endl;
-        t << convertToComment(m_doc);
-        t << endl;
-      }
-      t << m_name << m_spaces.left(MAX_OPTION_LENGTH-m_name.length()) << "=";
-      if (upd && !m_valueString.isEmpty())
-      {
-        writeStringValue(t,m_valueString);
-      }
-      else
-      {
-        writeIntValue(t,m_value);
-      }
-      t << "\n";
-    }
-    void writeXML(FTextStream&);
+    void writeTemplate(FTextStream &t,bool sl,bool upd);
     void init() { m_value = m_defValue; }
   private:
     int m_value;
@@ -303,26 +238,7 @@ class ConfigBool : public ConfigOption
     void convertStrToVal();
     void substEnvVars();
     void setValueString(const QCString &v) { m_valueString = v; }
-    void writeTemplate(FTextStream &t,bool sl,bool upd)
-    {
-      if (!sl)
-      {
-        t << endl;
-        t << convertToComment(m_doc);
-        t << endl;
-      }
-      t << m_name << m_spaces.left(MAX_OPTION_LENGTH-m_name.length()) << "=";
-      if (upd && !m_valueString.isEmpty())
-      {
-        writeStringValue(t,m_valueString);
-      }
-      else
-      {
-        writeBoolValue(t,m_value);
-      }
-      t << "\n";
-    }
-    void writeXML(FTextStream&);
+    void writeTemplate(FTextStream &t,bool sl,bool upd);
     void init() { m_value = m_defValue; }
   private:
     bool m_value;
@@ -335,15 +251,25 @@ class ConfigBool : public ConfigOption
 class ConfigObsolete : public ConfigOption
 {
   public:
-    ConfigObsolete(const char *name,OptionType t) : ConfigOption(t)  
+    ConfigObsolete(const char *name) : ConfigOption(O_Obsolete)  
     { m_name = name; }
-    void writeTemplate(FTextStream &,bool,bool) {}
+    void writeTemplate(FTextStream &,bool,bool);
+    void substEnvVars() {}
+};
+
+/** Section marker for compile time optional options
+ */
+class ConfigDisabled : public ConfigOption
+{
+  public:
+    ConfigDisabled(const char *name) : ConfigOption(O_Disabled)  
+    { m_name = name; }
+    void writeTemplate(FTextStream &,bool,bool);
     void substEnvVars() {}
-    void writeXML(FTextStream&);
 };
 
 
-// some convenience macros
+// some convenience macros for access the config options
 #define Config_getString(val)  Config::instance()->getString(__FILE__,__LINE__,val)
 #define Config_getInt(val)     Config::instance()->getInt(__FILE__,__LINE__,val)
 #define Config_getList(val)    Config::instance()->getList(__FILE__,__LINE__,val)
@@ -517,11 +443,19 @@ class Config
     /*! Adds an option that has become obsolete. */
     ConfigOption *addObsolete(const char *name)
     {
-      ConfigObsolete *option = new ConfigObsolete(name,ConfigOption::O_Obsolete);
+      ConfigObsolete *option = new ConfigObsolete(name);
       m_dict->insert(name,option);
       m_obsolete->append(option);
       return option;
     }
+    /*! Adds an option that has been disabled at compile time. */
+    ConfigOption *addDisabled(const char *name)
+    {
+      ConfigDisabled *option = new ConfigDisabled(name);
+      m_dict->insert(name,option);
+      m_disabled->append(option);
+      return option;
+    }
     /*! @} */
 
     /*! Writes a template configuration to stream \a t. If \a shortIndex
@@ -530,8 +464,7 @@ class Config
      */
     void writeTemplate(FTextStream &t,bool shortIndex,bool updateOnly);
 
-    /** Write XML representation of the config file */
-    void writeXML(FTextStream &t);
+    void setHeader(const char *header) { m_header = header; }
 
     /////////////////////////////
     // internal API
@@ -572,12 +505,29 @@ class Config
      */
     void create();
 
+    /*! Append user comment
+     */
+    void appendUserComment(const QCString &u)
+    {
+      m_userComment += u;
+    }
+    /*! Take the user comment and reset it internally
+     *  \returns user comment
+     */
+    QCString takeUserComment()
+    {
+      QCString result=m_userComment;
+      m_userComment.resize(0);
+      return result;
+    }
+
   protected:
 
     Config()
     { 
       m_options  = new QList<ConfigOption>;
       m_obsolete = new QList<ConfigOption>;
+      m_disabled = new QList<ConfigOption>;
       m_dict     = new QDict<ConfigOption>(257);
       m_options->setAutoDelete(TRUE);
       m_obsolete->setAutoDelete(TRUE);
@@ -588,15 +538,20 @@ class Config
     {
       delete m_options;
       delete m_obsolete;
+      delete m_disabled;
       delete m_dict;
     }
 
   private:
+    void checkFileName(const char *);
     QList<ConfigOption> *m_options;
     QList<ConfigOption> *m_obsolete;
+    QList<ConfigOption> *m_disabled;
     QDict<ConfigOption> *m_dict;
     static Config *m_instance;
+    QCString m_userComment;
     bool m_initialized;
+    QCString m_header;
 };
 
 #endif
