@@ -830,7 +830,9 @@ DBusXMLScanner::~DBusXMLScanner()
 
 void DBusXMLScanner::parseInput(const char * fileName,
                                 const char * /* fileBuf */,
-                                Entry * root)
+                                Entry *root,
+                                bool /*sameTranslationUnit*/,
+                                QStrList & /*filesInSameTranslationUnit*/)
 {
     QFile inputFile(fileName);
 
@@ -859,6 +861,7 @@ bool DBusXMLScanner::needsPreprocessing(const QCString & /* extension */)
 void DBusXMLScanner::parseCode(CodeOutputInterface & /* codeOutIntf */,
                                const char * /* scopeName */,
                                const QCString & /* input */,
+                               SrcLangExt /* lang */,
                                bool /* isExampleBlock */,
                                const char * /* exampleName */,
                                FileDef * /* fileDef */,
@@ -866,7 +869,8 @@ void DBusXMLScanner::parseCode(CodeOutputInterface & /* codeOutIntf */,
                                int /* endLine */,
                                bool /* inlineFragment */,
                                MemberDef * /* memberDef */,
-                               bool /*showLineNumbers*/)
+                               bool /*showLineNumbers*/,
+                               Definition * /* searchCtx */)
 { }
 
 void DBusXMLScanner::resetCodeParserState()
