@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * $Id: debug.cpp,v 1.7 2001/03/19 19:27:40 root Exp $
+ * 
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -20,7 +20,6 @@
 
 #include <qdict.h>
 
-#include "qtbc.h"
 #include "debug.h"
 
 //------------------------------------------------------------------------
