@@ -1,7 +1,7 @@
 /******************************************************************************
  * ftvhelp.cpp,v 1.0 2000/09/06 16:09:00
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -34,6 +34,8 @@
 #include "pagedef.h"
 #include "docparser.h"
 #include "htmldocvisitor.h"
+#include "filedef.h"
+#include "util.h"
 
 #define MAX_INDENT 1024
 
@@ -739,7 +741,7 @@ void FTVHelp::addContentsItem(bool isDir,
   
 }
 
-static QCString node2URL(FTVNode *n)
+static QCString node2URL(FTVNode *n,bool overruleFile=FALSE,bool srcLink=FALSE)
 {
   QCString url = n->file;
   if (!url.isEmpty() && url.at(0)=='!')  // relative URL
@@ -753,6 +755,18 @@ static QCString node2URL(FTVNode *n)
   }
   else // local file (with optional anchor)
   {
+    if (overruleFile && n->def && n->def->definitionType()==Definition::TypeFile)
+    {
+      FileDef *fd = (FileDef*)n->def;
+      if (srcLink)
+      {
+        url = fd->getSourceFileBase();
+      }
+      else
+      {
+        url = fd->getOutputFileBase();
+      }
+    }
     url+=Doxygen::htmlFileExtension;
     if (!n->anchor.isEmpty()) url+="#"+n->anchor;
   }
@@ -869,12 +883,14 @@ void FTVHelp::generateLink(FTextStream &t,FTVNode *n)
 static void generateBriefDoc(FTextStream &t,Definition *def)
 {
   QCString brief = def->briefDescription(TRUE);
+  //printf("*** %p: generateBriefDoc(%s)='%s'\n",def,def->name().data(),brief.data());
   if (!brief.isEmpty())
   {
     DocNode *root = validatingParseDoc(def->briefFile(),def->briefLine(),
         def,0,brief,FALSE,FALSE,0,TRUE,TRUE);
-    HtmlGenerator htmlGen;
-    HtmlDocVisitor *visitor = new HtmlDocVisitor(t,htmlGen,0);
+    QCString relPath = relativePathToRoot(def->getOutputFileBase());
+    HtmlCodeGenerator htmlGen(t,relPath);
+    HtmlDocVisitor *visitor = new HtmlDocVisitor(t,htmlGen,def,0);
     root->accept(visitor);
     delete visitor;
     delete root;
@@ -1012,7 +1028,7 @@ class NavIndexEntryList : public QList<NavIndexEntry>
   public:
     NavIndexEntryList() : QList<NavIndexEntry>() { setAutoDelete(TRUE); }
    ~NavIndexEntryList() {}
-    int compareItems(GCI item1,GCI item2)
+    int compareItems(QCollection::Item item1,QCollection::Item item2)
     {
       // sort list based on url
       return qstrcmp(((NavIndexEntry*)item1)->url,((NavIndexEntry*)item2)->url);
@@ -1085,7 +1101,24 @@ static bool generateJSTree(NavIndexEntryList &navIndex,FTextStream &t,
 
     if (n->addToNavIndex) // add entry to the navigation index
     {
-      navIndex.append(new NavIndexEntry(node2URL(n),pathToNode(n,n)));
+      if (n->def && n->def->definitionType()==Definition::TypeFile)
+      {
+        FileDef *fd = (FileDef*)n->def;
+        bool doc,src;
+        doc = fileVisibleInIndex(fd,src);
+        if (doc)
+        {
+          navIndex.append(new NavIndexEntry(node2URL(n,TRUE,FALSE),pathToNode(n,n)));
+        }
+        if (src)
+        {
+          navIndex.append(new NavIndexEntry(node2URL(n,TRUE,TRUE),pathToNode(n,n)));
+        }
+      }
+      else
+      {
+        navIndex.append(new NavIndexEntry(node2URL(n),pathToNode(n,n)));
+      }
     }
 
     if (n->separateIndex) // store items in a separate file for dynamic loading
@@ -1191,15 +1224,24 @@ static void generateJSNavTree(const QList<FTVNode> &nodeList)
       tsidx << "{" << endl;
       QListIterator<NavIndexEntry> li(navIndex);
       NavIndexEntry *e;
+      bool first=TRUE;
       for (li.toFirst();(e=li.current());) // for each entry
       {
         if (elemCount==0)
         {
-          t << "\"" << e->url << "\"," << endl;
+          if (!first)
+          {
+            t << "," << endl;
+          }
+          else
+          {
+            first=FALSE;
+          }
+          t << "\"" << e->url << "\"";
         }
         tsidx << "\"" << e->url << "\":[" << e->path << "]";
         ++li;
-        if (li.current()) tsidx << ","; // not last entry
+        if (li.current() && elemCount<maxElemCount-1) tsidx << ","; // not last entry
         tsidx << endl;
   
         elemCount++;
@@ -1217,8 +1259,10 @@ static void generateJSNavTree(const QList<FTVNode> &nodeList)
         }
       }
       tsidx << "};" << endl;
-      t << "];" << endl;
+      t << endl << "];" << endl;
     }
+    t << endl << "var SYNCONMSG = '"  << theTranslator->trPanelSynchronisationTooltip(FALSE) << "';"; 
+    t << endl << "var SYNCOFFMSG = '" << theTranslator->trPanelSynchronisationTooltip(TRUE)  << "';"; 
     t << endl << navtree_script;
   }
 }
@@ -1255,7 +1299,11 @@ void FTVHelp::generateTreeViewScripts()
     if (f.open(IO_WriteOnly))
     {
       FTextStream t(&f);
-      t << replaceColorMarkers(navtree_css);
+      t << substitute(
+              replaceColorMarkers(navtree_css),
+              "$width",
+              QCString().setNum(Config_getInt("TREEVIEW_WIDTH"))+"px"
+             );
     }
   }
 }
