@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * $Id: groupdef.h,v 1.18 2001/03/19 19:27:40 root Exp $
+ * 
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,13 +18,10 @@
 #ifndef GROUPDEF_H
 #define GROUPDEF_H
 
-#include "qtbc.h"
 #include "sortdict.h"
 #include "definition.h"
-#include "memberlist.h"
-#include "memberdef.h"
-#include "htmlhelp.h"
 
+class MemberList;
 class FileList;
 class ClassSDict;
 class FileDef;
@@ -41,6 +38,7 @@ class DirDef;
 class DirList;
 class FTVHelp;
 class Entry;
+class MemberDef;
 
 /** A model of a group of symbols. */
 class GroupDef : public Definition
@@ -90,7 +88,7 @@ class GroupDef : public Definition
     void setGroupScope(Definition *d) { groupScope = d; }
     Definition *getGroupScope() const { return groupScope; }
 
-    MemberList *getMemberList(MemberList::ListType lt) const;
+    MemberList *getMemberList(MemberListType lt) const;
     const QList<MemberList> &getMemberLists() const { return m_memberLists; }
 
     /* user defined member groups */
@@ -110,11 +108,11 @@ class GroupDef : public Definition
     void addMemberListToGroup(MemberList *,bool (MemberDef::*)() const);
 
   private: 
-    MemberList *createMemberList(MemberList::ListType lt);
-    void addMemberToList(MemberList::ListType lt,MemberDef *md);
-    void writeMemberDeclarations(OutputList &ol,MemberList::ListType lt,const QCString &title);
-    void writeMemberDocumentation(OutputList &ol,MemberList::ListType lt,const QCString &title);
-    void removeMemberFromList(MemberList::ListType lt,MemberDef *md);
+    MemberList *createMemberList(MemberListType lt);
+    void addMemberToList(MemberListType lt,MemberDef *md);
+    void writeMemberDeclarations(OutputList &ol,MemberListType lt,const QCString &title);
+    void writeMemberDocumentation(OutputList &ol,MemberListType lt,const QCString &title);
+    void removeMemberFromList(MemberListType lt,MemberDef *md);
     void writeGroupGraph(OutputList &ol);
     void writeFiles(OutputList &ol,const QCString &title);
     void writeNamespaces(OutputList &ol,const QCString &title);
@@ -132,6 +130,7 @@ class GroupDef : public Definition
     void endMemberDocumentation(OutputList &ol);
     void writeAuthorSection(OutputList &ol);
     void writeSummaryLinks(OutputList &ol);
+    void updateLanguage(const Definition *);
 
     QCString title;                      // title of the group
     bool titleSet;                       // true if title is not the same as the name
@@ -160,9 +159,9 @@ class GroupSDict : public SDict<GroupDef>
   public:
     GroupSDict(uint size) : SDict<GroupDef>(size) {}
     virtual ~GroupSDict() {}
-    int compareItems(GCI item1,GCI item2)
+    int compareItems(QCollection::Item item1,QCollection::Item item2)
     {
-      return strcmp(((GroupDef*)item1)->groupTitle(),((GroupDef*)item2)->groupTitle());
+      return qstrcmp(((GroupDef*)item1)->groupTitle(),((GroupDef*)item2)->groupTitle());
     }
 };
 
@@ -170,9 +169,9 @@ class GroupSDict : public SDict<GroupDef>
 class GroupList : public QList<GroupDef>
 {
   public:
-    int compareItems(GCI item1,GCI item2)
+    int compareItems(QCollection::Item item1,QCollection::Item item2)
     {
-      return strcmp(((GroupDef*)item1)->groupTitle(),((GroupDef*)item2)->groupTitle());
+      return qstrcmp(((GroupDef*)item1)->groupTitle(),((GroupDef*)item2)->groupTitle());
     }
 };
 
