@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -46,6 +46,8 @@
 #include "entry.h"
 #include "bufstr.h"
 #include "commentcnv.h"
+#include "config.h"
+#include "section.h"
 
 //-----------
 
@@ -93,7 +95,7 @@ static QCString       g_fileName;
 // as a title of the page, in effect making it a level0 header, so the
 // level of all other sections needs to be corrected as well.
 // This flag is TRUE if corrections are needed.
-static bool           g_correctSectionLevel;
+//static bool           g_correctSectionLevel;
 
 
 //----------
@@ -190,15 +192,16 @@ static QCString isBlockCommand(const char *data,int offset,int size)
   {
     return "}";
   }
-  else if (blockName=="dot"       || 
-           blockName=="code"      || 
-           blockName=="msc"       ||
-           blockName=="verbatim"  || 
-           blockName=="latexonly" || 
-           blockName=="htmlonly"  ||
-           blockName=="xmlonly"   ||
-           blockName=="rtfonly"   ||
-           blockName=="manonly"
+  else if (blockName=="dot"         || 
+           blockName=="code"        || 
+           blockName=="msc"         ||
+           blockName=="verbatim"    || 
+           blockName=="latexonly"   || 
+           blockName=="htmlonly"    ||
+           blockName=="xmlonly"     ||
+           blockName=="rtfonly"     ||
+           blockName=="manonly"     ||
+           blockName=="docbookonly"
      )
   {
     return "end"+blockName;
@@ -224,7 +227,7 @@ static QCString isBlockCommand(const char *data,int offset,int size)
 /** looks for the next emph char, skipping other constructs, and
  *  stopping when either it is found, or we are at the end of a paragraph.
  */
-static int findEmphasisChar(const char *data, int size, char c)
+static int findEmphasisChar(const char *data, int size, char c, int c_size)
 {
   int i = 1;
 
@@ -242,16 +245,25 @@ static int findEmphasisChar(const char *data, int size, char c)
       i++;
       continue;
     }
-    else if (data[i] == c)
+    else
     {
-      if (i<size-1 && isIdChar(i+1)) // to prevent touching some_underscore_identifier
+      // get length of emphasis token
+      int len = 0;
+      while (i+len<size && data[i+len]==c)
       {
-        i++;
-        continue;
+        len++;
       }
-      return i; // found it
-    }
 
+      if (len>0)
+      {
+        if (len!=c_size || (i<size-len && isIdChar(i+len))) // to prevent touching some_underscore_identifier
+        {
+          i=i+len;
+          continue;
+        }
+        return i; // found it
+      }
+    }
 
     // skipping a code span
     if (data[i]=='`')
@@ -275,12 +287,12 @@ static int findEmphasisChar(const char *data, int size, char c)
       {
         i++;
         int l = endBlockName.length();
-        while (i<size-l-1)
+        while (i<size-l)
         {
           if ((data[i]=='\\' || data[i]=='@') && // command
               data[i-1]!='\\' && data[i-1]!='@') // not escaped
           {
-            if (strncmp(&data[i+1],endBlockName,l)==0)
+            if (qstrncmp(&data[i+1],endBlockName,l)==0)
             {
               break;
             }
@@ -288,6 +300,10 @@ static int findEmphasisChar(const char *data, int size, char c)
           i++;
         }
       }
+      else if (i<size-1 && isIdChar(i+1)) // @cmd, stop processing, see bug 690385
+      {
+        return 0;
+      }
       else
       {
         i++;
@@ -318,7 +334,7 @@ static int processEmphasis1(GrowBuf &out, const char *data, int size, char c)
 
   while (i<size)
   {
-    len = findEmphasisChar(data+i, size-i, c);
+    len = findEmphasisChar(data+i, size-i, c, 1);
     if (len==0) return 0; 
     i+=len;
     if (i>=size) return 0; 
@@ -346,7 +362,7 @@ static int processEmphasis2(GrowBuf &out, const char *data, int size, char c)
 
   while (i<size)
   {
-    len = findEmphasisChar(data+i, size-i, c);
+    len = findEmphasisChar(data+i, size-i, c, 2);
     if (len==0)
     {
       return 0;
@@ -366,7 +382,7 @@ static int processEmphasis2(GrowBuf &out, const char *data, int size, char c)
   return 0;
 }
 
-/** Parsing single emphase.
+/** Parsing tripple emphasis.
  *  Finds the first closing tag, and delegates to the other emph 
  */
 static int processEmphasis3(GrowBuf &out, const char *data, int size, char c)
@@ -375,7 +391,7 @@ static int processEmphasis3(GrowBuf &out, const char *data, int size, char c)
 
   while (i<size)
   {
-    len = findEmphasisChar(data+i, size-i, c);
+    len = findEmphasisChar(data+i, size-i, c, 3);
     if (len==0)
     {
       return 0;
@@ -425,6 +441,60 @@ static int processEmphasis3(GrowBuf &out, const char *data, int size, char c)
   return 0;
 }
 
+/** Process ndash and mdashes */
+static int processNmdash(GrowBuf &out,const char *data,int off,int size)
+{
+  // precondition: data[0]=='-'
+  int i=1;
+  int count=1;
+  if (i<size && data[i]=='-') // found --
+  {
+    count++,i++;
+  }
+  if (i<size && data[i]=='-') // found ---
+  {
+    count++,i++;
+  }
+  if (i<size && data[i]=='-') // found ----
+  {
+    count++;
+  }
+  if (count==2 && (off<8 || qstrncmp(data-8,"operator",8)!=0)) // -- => ndash
+  {
+    out.addStr("&ndash;");
+    return 2;
+  }
+  else if (count==3) // --- => ndash
+  {
+    out.addStr("&mdash;");
+    return 3;
+  }
+  // not an ndash or mdash
+  return 0;
+}
+
+/** Process quoted section "...", can contain one embedded newline */
+static int processQuoted(GrowBuf &out,const char *data,int,int size)
+{
+  int i=1;
+  int nl=0;
+  while (i<size && data[i]!='"' && nl<2) 
+  {
+    if (data[i]=='\n') nl++;
+    i++;
+  }
+  if (i<size && data[i]=='"' && nl<2)
+  {
+    out.addStr(data,i+1);
+    return i+1;
+  }
+  // not a quoted section
+  return 0;
+}
+
+/** Process a HTML tag. Note that <pre>..</pre> are treated specially, in
+ *  the sense that all code inside is written unprocessed
+ */
 static int processHtmlTag(GrowBuf &out,const char *data,int offset,int size)
 {
   if (offset>0 && data[-1]=='\\') return 0; // escaped <
@@ -518,23 +588,6 @@ static int processEmphasis(GrowBuf &out,const char *data,int offset,int size)
     return 0;
   }
 
-#if 0
-  if (offset>0 && size>1 && (isIdChar(-1) || data[-1]==data[0]))
-  {
-    if (isIdChar(1) || data[-1]==data[0])
-    {
-      // avoid processing interal * and  _ as cmd_id, or 4*10 as emphasis,
-      // also x**2,y*2 should not be processed
-      return 0;
-    }
-    else if (size>2 && data[0]==data[1] && isIdChar(2))
-    {
-      // avoid processing interal ** and  __ such as cmd__id__bla, 
-      // or 4**10,5**10 as emphasis
-      return 0;
-    }
-  }
-#endif
   char c = data[0];
   int ret;
   if (size>2 && data[1]!=c) // _bla or *bla
@@ -922,12 +975,12 @@ static int processSpecialCommand(GrowBuf &out, const char *data, int offset, int
   if (!endBlockName.isEmpty())
   {
     int l = endBlockName.length();
-    while (i<size-l-1)
+    while (i<size-l)
     {
       if ((data[i]=='\\' || data[i]=='@') && // command
           data[i-1]!='\\' && data[i-1]!='@') // not escaped
       {
-        if (strncmp(&data[i+1],endBlockName,l)==0)
+        if (qstrncmp(&data[i+1],endBlockName,l)==0)
         {
           //printf("found end at %d\n",i);
           out.addStr(data,i+1+l);
@@ -1142,24 +1195,16 @@ static int isHRuler(const char *data,int size)
 static QCString extractTitleId(QCString &title)
 {
   //static QRegExp r1("^[a-z_A-Z][a-z_A-Z0-9\\-]*:");
-  static QRegExp r2("\\{#[a-z_A-Z][a-z_A-Z0-9\\-]*\\}$");
+  static QRegExp r2("\\{#[a-z_A-Z][a-z_A-Z0-9\\-]*\\}");
   int l=0;
   int i = r2.match(title,0,&l);
-  if (i!=-1) // found {#id} style id
+  if (i!=-1 && title.mid(i+l).stripWhiteSpace().isEmpty()) // found {#id} style id
   {
     QCString id = title.mid(i+2,l-3);
-    title = title.left(i)+title.mid(i+l);
+    title = title.left(i);
     //printf("found id='%s' title='%s'\n",id.data(),title.data());
     return id;
   }
-  //i = r1.match(title,0,&l);
-  //if (i!=-1) // found id: style id
-  //{
-  //  QCString id = title.mid(i,l-1);
-  //  title = title.left(i)+title.mid(i+l);
-  //  //printf("found id='%s' title='%s'\n",id.data(),title.data());
-  //  return id;
-  //}
   //printf("no id found in title '%s'\n",title.data());
   return "";
 }
@@ -1404,11 +1449,11 @@ static bool isCodeBlock(const char *data,int offset,int size,int &indent)
  */
 int findTableColumns(const char *data,int size,int &start,int &end,int &columns)
 {
-  int i=0;
+  int i=0,n=0;
   int eol;
   // find start character of the table line
   while (i<size && data[i]==' ') i++;
-  if (i<size && data[i]=='|') i++; // leading | does not count
+  if (i<size && data[i]=='|' && data[i]!='\n') i++,n++; // leading | does not count
   start = i;
 
   // find end character of the table line
@@ -1416,20 +1461,25 @@ int findTableColumns(const char *data,int size,int &start,int &end,int &columns)
   eol=i+1;
   i--;
   while (i>0 && data[i]==' ') i--;
-  if (i>0 && data[i]=='|') i--; // trailing | does not count
+  if (i>0 && data[i]=='|') i--,n++; // trailing | does not count
   end = i;
 
   // count columns between start and end
-  columns=1;
+  columns=0;
   if (end>start)
   {
     i=start;
-    while (i<=end)
+    while (i<=end) // look for more column markers
     {
       if (data[i]=='|' && (i==0 || data[i-1]!='\\')) columns++;
+      if (columns==1) columns++; // first | make a non-table into a two column table
       i++;
     }
   }
+  if (n==2 && columns==0) // table row has | ... |
+  {
+    columns++;
+  }
   //printf("findTableColumns(start=%d,end=%d,columns=%d) eol=%d\n",
   //    start,end,columns,eol);
   return eol;
@@ -1442,7 +1492,7 @@ static bool isTableBlock(const char *data,int size)
 
   // the first line should have at least two columns separated by '|'
   int i = findTableColumns(data,size,start,end,cc0);
-  if (i>=size || cc0<2) 
+  if (i>=size || cc0<1) 
   {
     //printf("isTableBlock: no |'s in the header\n");
     return FALSE;
@@ -1535,9 +1585,9 @@ static int writeTableBlock(GrowBuf &out,const char *data,int size)
     out.addStr("<th");
     switch (columnAlignment[k])
     {
-      case AlignLeft:   out.addStr(" align=left"); break;
-      case AlignRight:  out.addStr(" align=right"); break;
-      case AlignCenter: out.addStr(" align=center"); break;
+      case AlignLeft:   out.addStr(" align=\"left\""); break;
+      case AlignRight:  out.addStr(" align=\"right\""); break;
+      case AlignCenter: out.addStr(" align=\"center\""); break;
       case AlignNone:   break;
     }
     out.addStr(">");
@@ -1547,6 +1597,7 @@ static int writeTableBlock(GrowBuf &out,const char *data,int size)
     }
     m++;
   }
+  out.addStr("\n</th>\n");
 
   // write table cells
   while (i<size)
@@ -1566,9 +1617,9 @@ static int writeTableBlock(GrowBuf &out,const char *data,int size)
         out.addStr("<td");
         switch (columnAlignment[k])
         {
-          case AlignLeft:   out.addStr(" align=left"); break;
-          case AlignRight:  out.addStr(" align=right"); break;
-          case AlignCenter: out.addStr(" align=center"); break;
+          case AlignLeft:   out.addStr(" align=\"left\""); break;
+          case AlignRight:  out.addStr(" align=\"right\""); break;
+          case AlignCenter: out.addStr(" align=\"center\""); break;
           case AlignNone:   break;
         }
         out.addStr(">");
@@ -1590,7 +1641,7 @@ static int writeTableBlock(GrowBuf &out,const char *data,int size)
     i+=ret;
   }
 
-  out.addStr("</table>\n");
+  out.addStr("</table> ");
 
   delete[] columnAlignment;
   return i;
@@ -1608,8 +1659,8 @@ void writeOneLineHeaderOrRuler(GrowBuf &out,const char *data,int size)
   }
   else if ((level=isAtxHeader(data,size,header,id)))
   {
-    if (level==1) g_correctSectionLevel=FALSE;
-    if (g_correctSectionLevel) level--;
+    //if (level==1) g_correctSectionLevel=FALSE;
+    //if (g_correctSectionLevel) level--;
     QCString hTag;
     if (level<5 && !id.isEmpty())
     {
@@ -1638,7 +1689,7 @@ void writeOneLineHeaderOrRuler(GrowBuf &out,const char *data,int size)
       {
         g_current->anchors->append(si);
       }
-      Doxygen::sectionDict.append(header,si);
+      Doxygen::sectionDict->append(header,si);
     }
     else
     {
@@ -1679,7 +1730,8 @@ static int writeBlockQuote(GrowBuf &out,const char *data,int size)
       else if (j>0 && data[j-1]=='>') indent=j+1;
       j++;
     }
-    if (j>0 && data[j-1]=='>') // disqualify last > if not followed by space
+    if (j>0 && data[j-1]=='>' && 
+        !(j==size || data[j]=='\n')) // disqualify last > if not followed by space
     {
       indent--;
       j--;
@@ -1727,7 +1779,8 @@ static int writeCodeBlock(GrowBuf &out,const char *data,int size,int refIndent)
     int j=i;
     int indent=0;
     while (j<end && data[j]==' ') j++,indent++;
-    //printf("j=%d end=%d indent=%d refIndent=%d data={%s}\n",j,end,indent,refIndent,QCString(data+i).left(end-i-1).data());
+    //printf("j=%d end=%d indent=%d refIndent=%d tabSize=%d data={%s}\n",
+    //    j,end,indent,refIndent,Config_getInt("TAB_SIZE"),QCString(data+i).left(end-i-1).data());
     if (j==end-1) // empty line 
     {
       emptyLines++;
@@ -1778,16 +1831,17 @@ static void findEndOfLine(GrowBuf &out,const char *data,int size,
        )
     {
       QCString endBlockName = isBlockCommand(data+end-1,end-1,size-(end-1));
+      end++;
       if (!endBlockName.isEmpty())
       {
         int l = endBlockName.length();
-        for (;end<size-l;end++) // search for end of block marker
+        for (;end<size-l-1;end++) // search for end of block marker
         {
           if ((data[end]=='\\' || data[end]=='@') &&
               data[end-1]!='\\' && data[end-1]!='@'
              )
           {
-            if (strncmp(&data[end+1],endBlockName,l)==0)
+            if (qstrncmp(&data[end+1],endBlockName,l)==0)
             {
               if (pi!=-1) // output previous line if available
               {
@@ -1805,10 +1859,6 @@ static void findEndOfLine(GrowBuf &out,const char *data,int size,
           }
         }
       }
-      else
-      {
-        end++;
-      }
     }
     else if (nb==0 && data[end-1]=='<' && end<size-6 &&
              (end<=1 || (data[end-2]!='\\' && data[end-2]!='@'))
@@ -1943,13 +1993,14 @@ static QCString processBlocks(const QCString &s,int indent)
       //printf("isHeaderLine(%s)=%d\n",QCString(data+i).left(size-i).data(),level);
       if ((level=isHeaderline(data+i,size-i))>0)
       {
-        if (level==1) g_correctSectionLevel=FALSE;
-        if (g_correctSectionLevel) level--;
+        //if (level==1) g_correctSectionLevel=FALSE;
+        //if (g_correctSectionLevel) level--;
         //printf("Found header at %d-%d\n",i,end);
         while (pi<size && data[pi]==' ') pi++;
         QCString header,id;
         convertStringFragment(header,data+pi,i-pi-1);
         id = extractTitleId(header);
+        //printf("header='%s' is='%s'\n",header.data(),id.data());
         if (!header.isEmpty())
         {
           if (!id.isEmpty())
@@ -1958,20 +2009,20 @@ static QCString processBlocks(const QCString &s,int indent)
             out.addStr(id);
             out.addStr(" ");
             out.addStr(header);
-            out.addStr("\n");
+            out.addStr("\n\n");
             SectionInfo *si = new SectionInfo(g_fileName,id,header,
                 level==1 ? SectionInfo::Section : SectionInfo::Subsection,level);
             if (g_current)
             {
               g_current->anchors->append(si);
             }
-            Doxygen::sectionDict.append(header,si);
+            Doxygen::sectionDict->append(header,si);
           }
           else
           {
             out.addStr(level==1?"<h1>":"<h2>");
             out.addStr(header);
-            out.addStr(level==1?"</h1>\n":"</h2>\n");
+            out.addStr(level==1?"\n</h1>\n":"\n</h2>\n");
           }
         }
         else
@@ -1997,14 +2048,14 @@ static QCString processBlocks(const QCString &s,int indent)
         //printf("Found FencedCodeBlock lang='%s' start=%d end=%d code={%s}\n",
         //       lang.data(),blockStart,blockEnd,QCString(data+pi+blockStart).left(blockEnd-blockStart).data());
         if (!lang.isEmpty() && lang.at(0)=='.') lang=lang.mid(1);
-        if (lang.isEmpty()) out.addStr("@verbatim"); else out.addStr("@code");
+        out.addStr("@code");
         if (!lang.isEmpty())
         {
           out.addStr("{"+lang+"}");
         }
         out.addStr(data+pi+blockStart,blockEnd-blockStart);       
         out.addStr("\n");
-        if (lang.isEmpty()) out.addStr("@endverbatim"); else out.addStr("@endcode");
+        out.addStr("@endcode");
         i=pi+blockOffset;
         pi=-1;
         end=i+1;
@@ -2054,12 +2105,17 @@ static QCString processBlocks(const QCString &s,int indent)
 
 static QCString extractPageTitle(QCString &docs,QCString &id)
 {
+  int ln=0;
   // first first non-empty line
   QCString title;
   const char *data = docs.data();
   int i=0;
   int size=docs.size();
-  while (i<size && (data[i]==' ' || data[i]=='\n')) i++;
+  while (i<size && (data[i]==' ' || data[i]=='\n')) 
+  {
+    if (data[i]=='\n') ln++;
+    i++;
+  }
   if (i>=size) return "";
   int end1=i+1;
   while (end1<size && data[end1-1]!='\n') end1++;
@@ -2067,13 +2123,16 @@ static QCString extractPageTitle(QCString &docs,QCString &id)
   // first line from i..end1
   if (end1<size)
   {
+    ln++;
     // second line form end1..end2
     int end2=end1+1;
     while (end2<size && data[end2-1]!='\n') end2++;
     if (isHeaderline(data+end1,size-end1))
     {
       convertStringFragment(title,data+i,end1-i-1);
-      docs=docs.mid(end2);
+      QCString lns;
+      lns.fill('\n',ln);
+      docs=lns+docs.mid(end2);
       id = extractTitleId(title);
       //printf("extractPageTitle(title='%s' docs='%s' id='%s')\n",title.data(),docs.data(),id.data());
       return title;
@@ -2106,6 +2165,7 @@ static QCString detab(const QCString &s,int &refIndent)
       case '\t': // expand tab
         {
           int stop = tabSize - (col%tabSize);
+          //printf("expand at %d stop=%d\n",col,stop);
           col+=stop;
           while (stop--) out.addChar(' '); 
         }
@@ -2120,6 +2180,18 @@ static QCString detab(const QCString &s,int &refIndent)
         break;
       default: // non-whitespace => update minIndent
         out.addChar(c);
+        if (c<0 && i<size) // multibyte sequence
+        {
+          out.addChar(data[i++]); // >= 2 bytes
+          if (((uchar)c&0xE0)==0xE0 && i<size)
+          {
+            out.addChar(data[i++]); // 3 bytes
+          }
+          if (((uchar)c&0xF0)==0xF0 && i<size)
+          {
+            out.addChar(data[i++]); // 4 byres
+          }
+        }
         if (col<minIndent) minIndent=col;
         col++;
     }
@@ -2134,6 +2206,23 @@ static QCString detab(const QCString &s,int &refIndent)
 
 QCString processMarkdown(const QCString &fileName,Entry *e,const QCString &input)
 {
+  static bool init=FALSE;
+  if (!init)
+  {
+    // setup callback table for special characters
+    g_actions[(unsigned int)'_']=processEmphasis;
+    g_actions[(unsigned int)'*']=processEmphasis;
+    g_actions[(unsigned int)'`']=processCodeSpan;
+    g_actions[(unsigned int)'\\']=processSpecialCommand;
+    g_actions[(unsigned int)'@']=processSpecialCommand;
+    g_actions[(unsigned int)'[']=processLink;
+    g_actions[(unsigned int)'!']=processLink;
+    g_actions[(unsigned int)'<']=processHtmlTag;
+    g_actions[(unsigned int)'-']=processNmdash;
+    g_actions[(unsigned int)'"']=processQuoted;
+    init=TRUE;
+  }
+
   g_linkRefs.setAutoDelete(TRUE);
   g_linkRefs.clear();
   g_current = e;
@@ -2144,23 +2233,15 @@ QCString processMarkdown(const QCString &fileName,Entry *e,const QCString &input
   int refIndent;
   // for replace tabs by spaces
   QCString s = detab(input,refIndent);
+  //printf("======== DeTab =========\n---- output -----\n%s\n---------\n",s.data());
   // then process quotation blocks (as these may contain other blocks)
   s = processQuotations(s,refIndent);
   //printf("======== Quotations =========\n---- output -----\n%s\n---------\n",s.data());
   // then process block items (headers, rules, and code blocks, references)
   s = processBlocks(s,refIndent);
   //printf("======== Blocks =========\n---- output -----\n%s\n---------\n",s.data());
-  int size=s.length();
-  g_actions['_']=processEmphasis;
-  g_actions['*']=processEmphasis;
-  g_actions['`']=processCodeSpan;
-  g_actions['\\']=processSpecialCommand;
-  g_actions['@']=processSpecialCommand;
-  g_actions['[']=processLink;
-  g_actions['!']=processLink;
-  g_actions['<']=processHtmlTag;
   // finally process the inline markup (links, emphasis and code spans)
-  processInline(out,s,size);
+  processInline(out,s,s.length());
   out.addChar(0);
   Debug::print(Debug::Markdown,0,"======== Markdown =========\n---- input ------- \n%s\n---- output -----\n%s\n---------\n",input.data(),out.get());
   return out.get();
@@ -2170,27 +2251,40 @@ QCString processMarkdown(const QCString &fileName,Entry *e,const QCString &input
 
 void MarkdownFileParser::parseInput(const char *fileName, 
                 const char *fileBuf, 
-                Entry *root)
+                Entry *root,
+                bool /*sameTranslationUnit*/,
+                QStrList & /*filesInSameTranslationUnit*/)
 {
   Entry *current = new Entry;
   current->lang = SrcLangExt_Markdown;
   current->fileName = fileName;
   current->docFile  = fileName;
-  int len = strlen(fileBuf);
+  current->docLine  = 1;
+  int len = qstrlen(fileBuf);
   BufStr input(len);
   BufStr output(len);
-  input.addArray(fileBuf,strlen(fileBuf));
+  input.addArray(fileBuf,qstrlen(fileBuf));
   input.addChar('\0');
   convertCppComments(&input,&output,fileName);
   output.addChar('\0');
   QCString docs = output.data();
   QCString id;
   QCString title=extractPageTitle(docs,id).stripWhiteSpace();
-  g_correctSectionLevel = !title.isEmpty();
-  QCString baseName = substitute(QFileInfo(fileName).baseName().utf8()," ","_");
+  //g_correctSectionLevel = !title.isEmpty();
+  QCString baseFn  = stripFromPath(QFileInfo(fileName).absFilePath().utf8());
+  int i = baseFn.findRev('.');
+  if (i!=-1) baseFn = baseFn.left(i);
+  QCString titleFn = QFileInfo(fileName).baseName().utf8();
+  QCString fn      = QFileInfo(fileName).fileName().utf8();
+  QCString baseName = substitute(substitute(baseFn," ","_"),"/","_");
+  static QCString mdfileAsMainPage = Config_getString("USE_MDFILE_AS_MAINPAGE");
   if (id.isEmpty()) id = "md_"+baseName;
-  if (title.isEmpty()) title = baseName;
-  if (id=="mainpage" || id=="index")
+  if (title.isEmpty()) title = titleFn;
+  if (fn==mdfileAsMainPage)
+  {
+    docs.prepend("@mainpage\n");
+  }
+  else if (id=="mainpage" || id=="index")
   {
     docs.prepend("@mainpage "+title+"\n");
   }
@@ -2238,12 +2332,13 @@ void MarkdownFileParser::parseInput(const char *fileName,
 
   // restore setting
   Doxygen::markdownSupport = markdownEnabled;
-  g_correctSectionLevel = FALSE;
+  //g_correctSectionLevel = FALSE;
 }
 
 void MarkdownFileParser::parseCode(CodeOutputInterface &codeOutIntf,
                const char *scopeName,
                const QCString &input,
+               SrcLangExt lang,
                bool isExampleBlock,
                const char *exampleName,
                FileDef *fileDef,
@@ -2251,15 +2346,16 @@ void MarkdownFileParser::parseCode(CodeOutputInterface &codeOutIntf,
                int endLine,
                bool inlineFragment,
                MemberDef *memberDef,
-               bool showLineNumbers
+               bool showLineNumbers,
+               Definition *searchCtx
               )
 {
   ParserInterface *pIntf = Doxygen::parserManager->getParser("*.cpp");
   if (pIntf!=this)
   {
     pIntf->parseCode(
-       codeOutIntf,scopeName,input,isExampleBlock,exampleName,
-       fileDef,startLine,endLine,inlineFragment,memberDef,showLineNumbers);
+       codeOutIntf,scopeName,input,lang,isExampleBlock,exampleName,
+       fileDef,startLine,endLine,inlineFragment,memberDef,showLineNumbers,searchCtx);
   }
 }
 
