@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * $Id: msc.h,v 1.14 2001/03/19 19:27:40 root Exp $
+ * 
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,15 +18,20 @@
 #ifndef _MSC_H
 #define _MSC_H
 
-#include "qtbc.h"
+class QCString;
+class FTextStream;
 
 enum MscOutputFormat { MSC_BITMAP , MSC_EPS };
 
 void writeMscGraphFromFile(const char *inFile,const char *outDir,
                            const char *outFile,MscOutputFormat format);
 
-QString getMscImageMapFromFile(const QString& inFile, const QString& outDir,
-                               const QCString& relPath,const QString& context);
+QCString getMscImageMapFromFile(const QCString& inFile, const QCString& outDir,
+                                const QCString& relPath,const QCString& context);
+
+void writeMscImageMapFromFile(FTextStream &t,const QCString &inFile,
+                              const QCString &outDir, const QCString &relPath,
+                              const QCString &baseName, const QCString &context);
 
 #endif
 
