@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * $Id: namespacedef.h,v 1.18 2001/03/19 19:27:41 root Exp $
+ * 
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,13 +18,12 @@
 #ifndef NAMESPACEDEF_H
 #define NAMESPACEDEF_H
 
-#include "qtbc.h"
 #include <qstrlist.h>
 #include <qdict.h>
 #include "sortdict.h"
 #include "definition.h"
-#include "memberlist.h"
 
+class MemberList;
 class ClassDef;
 class ClassList;
 class OutputList;
@@ -34,15 +33,18 @@ class NamespaceList;
 class MemberGroupSDict;
 class NamespaceSDict;
 
+/** A model of a namespace symbol. */
 class NamespaceDef : public Definition
 {
   public:
-    NamespaceDef(const char *defFileName,int defLine,
+    NamespaceDef(const char *defFileName,int defLine,int defColumn,
                  const char *name,const char *ref=0,
-                 const char *refFile=0);
+                 const char *refFile=0,const char*type=0,
+                 bool isPublished=false);
    ~NamespaceDef();
     DefType definitionType() const { return TypeNamespace; }
     QCString getOutputFileBase() const;
+    QCString anchor() const { return QCString(); }
     void insertUsedFile(const char *fname);
     
     void writeDocumentation(OutputList &ol);
@@ -60,8 +62,12 @@ class NamespaceDef : public Definition
     void addUsingDeclaration(Definition *def);
     SDict<Definition> *getUsedClasses() const { return usingDeclList; }
     void combineUsingRelations();
-    QCString displayName() const;
-    
+    QCString displayName(bool=TRUE) const;
+    QCString localName() const;
+
+    bool isConstantGroup() const { return CONSTANT_GROUP == m_type; }
+    bool isModule()        const { return MODULE == m_type; }
+
     bool isLinkableInProject() const;
     bool isLinkable() const;
     void addMembersToMemberGroup();
@@ -73,7 +79,7 @@ class NamespaceDef : public Definition
     void addInnerCompound(Definition *d);
     void addListReferences();
     
-    MemberList *getMemberList(MemberList::ListType lt) const;
+    MemberList *getMemberList(MemberListType lt) const;
     const QList<MemberList> &getMemberLists() const { return m_memberLists; }
     MemberDef    *getMemberByName(const QCString &) const;
 
@@ -89,21 +95,24 @@ class NamespaceDef : public Definition
     bool visited;
 
   private:
-    MemberList *createMemberList(MemberList::ListType lt);
-    void addMemberToList(MemberList::ListType lt,MemberDef *md);
-    void writeMemberDeclarations(OutputList &ol,MemberList::ListType lt,const QCString &title);
-    void writeMemberDocumentation(OutputList &ol,MemberList::ListType lt,const QCString &title);
+    MemberList *createMemberList(MemberListType lt);
+    void addMemberToList(MemberListType lt,MemberDef *md);
+    void writeMemberDeclarations(OutputList &ol,MemberListType lt,const QCString &title);
+    void writeMemberDocumentation(OutputList &ol,MemberListType lt,const QCString &title);
     void writeDetailedDescription(OutputList &ol,const QCString &title);
     void writeBriefDescription(OutputList &ol);
     void startMemberDeclarations(OutputList &ol);
     void endMemberDeclarations(OutputList &ol);
     void writeClassDeclarations(OutputList &ol,const QCString &title);
-    void writeNamespaceDeclarations(OutputList &ol,const QCString &title);
+    void writeInlineClasses(OutputList &ol);
+    void writeNamespaceDeclarations(OutputList &ol,const QCString &title,
+            bool isConstantGroup=false);
     void writeMemberGroups(OutputList &ol);
     void writeAuthorSection(OutputList &ol);
     void startMemberDocumentation(OutputList &ol);
     void endMemberDocumentation(OutputList &ol);
     void writeSummaryLinks(OutputList &ol);
+    void addNamespaceAttributes(OutputList &ol);
 
     QCString              fileName;
     QStrList              files;
@@ -118,21 +127,24 @@ class NamespaceDef : public Definition
     ClassSDict           *classSDict;
     NamespaceSDict       *namespaceSDict;
     bool                  m_subGrouping;
-    bool                  m_isCSharp;
+    enum { NAMESPACE, MODULE, CONSTANT_GROUP } m_type;
+    bool m_isPublished;
 };
 
+/** A list of NamespaceDef objects. */
 class NamespaceList : public QList<NamespaceDef>
 { 
   public:
    ~NamespaceList() {}
-    int compareItems(GCI item1,GCI item2)
+    int compareItems(QCollection::Item item1,QCollection::Item item2)
     {
-      return stricmp(((NamespaceDef *)item1)->name(),
+      return qstricmp(((NamespaceDef *)item1)->name(),
                     ((NamespaceDef *)item2)->name()
                    );
     }
 };
 
+/** An iterator for NamespaceDef objects in a NamespaceList. */
 class NamespaceListIterator : public QListIterator<NamespaceDef>
 {
   public:
@@ -140,6 +152,7 @@ class NamespaceListIterator : public QListIterator<NamespaceDef>
       QListIterator<NamespaceDef>(l) {}
 };
 
+/** An unsorted dictionary of NamespaceDef objects. */
 class NamespaceDict : public QDict<NamespaceDef>
 {
   public:
@@ -147,18 +160,20 @@ class NamespaceDict : public QDict<NamespaceDef>
    ~NamespaceDict() {}
 };
 
+/** A sorted dictionary of NamespaceDef objects. */
 class NamespaceSDict : public SDict<NamespaceDef>
 {
   public:
     NamespaceSDict(int size=17) : SDict<NamespaceDef>(size) {}
    ~NamespaceSDict() {}
-    int compareItems(GCI item1,GCI item2)
+    int compareItems(QCollection::Item item1,QCollection::Item item2)
     {
-      return stricmp(((NamespaceDef *)item1)->name(),
+      return qstricmp(((NamespaceDef *)item1)->name(),
                     ((NamespaceDef *)item2)->name()
                    );
     }
-    void writeDeclaration(OutputList &ol,const char *title,bool localName=FALSE);
+    void writeDeclaration(OutputList &ol,const char *title,
+            bool isConstantGroup=false, bool localName=FALSE);
     bool declVisible() const;
 };
 
