@@ -1,3 +1,20 @@
+/******************************************************************************
+ *
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
+ *
+ * Permission to use, copy, modify, and distribute this software and its
+ * documentation under the terms of the GNU General Public License is hereby 
+ * granted. No representations are made about the suitability of this software 
+ * for any purpose. It is provided "as is" without express or implied warranty.
+ * See the GNU General Public License for more details.
+ *
+ * Documents produced by Doxygen are derivative works derived from the
+ * input used in their production; they are not affected by this license.
+ *
+ */
+
+#include <qregexp.h>
+
 #include "pagedef.h"
 #include "groupdef.h"
 #include "docparser.h"
@@ -6,17 +23,18 @@
 #include "outputlist.h"
 #include "doxygen.h"
 #include "language.h"
-#include <qregexp.h>
-
+#include "namespacedef.h"
+#include "reflist.h"
 
 PageDef::PageDef(const char *f,int l,const char *n,
                  const char *d,const char *t)
- : Definition(f,l,n), m_title(t)
+ : Definition(f,l,1,n), m_title(t)
 {
   setDocumentation(d,f,l);
   m_subPageDict = new PageSDict(7);
   m_pageScope = 0;
   m_nestingLevel = 0;
+  m_showToc = FALSE;
 }
 
 PageDef::~PageDef()
@@ -31,7 +49,7 @@ void PageDef::findSectionsInDocumentation()
 
 GroupDef *PageDef::getGroupDef() const 
 { 
-  LockingPtr<GroupList> groups = partOfGroups();
+  GroupList *groups = partOfGroups();
   return groups!=0 ? groups->getFirst() : 0; 
 }
 
@@ -43,6 +61,20 @@ QCString PageDef::getOutputFileBase() const
     return m_fileName; 
 }
 
+void PageDef::setFileName(const char *name) 
+{ 
+  static bool shortNames = Config_getBool("SHORT_NAMES");
+  if (shortNames)
+  {
+    m_fileName = convertNameToFile(name);
+  }
+  else
+  {
+    m_fileName = name; 
+  }
+}
+
+
 void PageDef::addInnerCompound(Definition *def)
 {
   if (def->definitionType()==Definition::TypePage)
@@ -72,13 +104,12 @@ void PageDef::writeDocumentation(OutputList &ol)
   static bool generateTreeView = Config_getBool("GENERATE_TREEVIEW");
 
   //outputList->disable(OutputGenerator::Man);
-  QCString pageName;
-  pageName=escapeCharsInString(name(),FALSE,TRUE);
+  QCString pageName,manPageName;
+  pageName    = escapeCharsInString(name(),FALSE,TRUE);
+  manPageName = escapeCharsInString(name(),TRUE,TRUE);
 
   //printf("PageDef::writeDocumentation: %s\n",getOutputFileBase().data());
 
-  startFile(ol,getOutputFileBase(),pageName,title(),HLI_Pages,!generateTreeView);
-
   ol.pushGeneratorState();
   //1.{ 
 
@@ -94,6 +125,16 @@ void PageDef::writeDocumentation(OutputList &ol)
     ol.enable(OutputGenerator::Html);
   }
 
+  ol.pushGeneratorState();
+  //2.{ 
+  ol.disableAllBut(OutputGenerator::Man);
+  startFile(ol,getOutputFileBase(),manPageName,title(),HLI_Pages,!generateTreeView);
+  ol.enableAll();
+  ol.disable(OutputGenerator::Man);
+  startFile(ol,getOutputFileBase(),pageName,title(),HLI_Pages,!generateTreeView);
+  ol.popGeneratorState();
+  //2.} 
+
   if (!generateTreeView)
   {
     if (getOuterScope()!=Doxygen::globalScope && !Config_getBool("DISABLE_INDEX"))
@@ -102,13 +143,19 @@ void PageDef::writeDocumentation(OutputList &ol)
     }
     ol.endQuickIndices();
   }
+  SectionInfo *si=Doxygen::sectionDict->find(name());
 
   // save old generator state and write title only to Man generator
   ol.pushGeneratorState();
   //2.{
   ol.disableAllBut(OutputGenerator::Man);
-  ol.startTitleHead(pageName);
-  ol.endTitleHead(pageName, pageName);
+  ol.startTitleHead(manPageName);
+  ol.endTitleHead(manPageName, manPageName);
+  if (si)
+  {
+    ol.generateDoc(docFile(),docLine(),this,0,si->title,TRUE,FALSE,0,TRUE,FALSE);
+    ol.endSection(si->label,si->type);
+  }
   ol.popGeneratorState();
   //2.}
 
@@ -117,13 +164,12 @@ void PageDef::writeDocumentation(OutputList &ol)
   //2.{
   ol.disable(OutputGenerator::Latex);
   ol.disable(OutputGenerator::RTF);
-  SectionInfo *si=0;
-  if (!title().isEmpty() && !name().isEmpty() &&
-      (si=Doxygen::sectionDict.find(name()))!=0)
+  ol.disable(OutputGenerator::Man);
+  if (!title().isEmpty() && !name().isEmpty() && si!=0)
   {
     //ol.startSection(si->label,si->title,si->type);
     startTitle(ol,getOutputFileBase(),this);
-    ol.parseDoc(docFile(),docLine(),this,0,si->title,TRUE,FALSE,0,TRUE,FALSE);
+    ol.generateDoc(docFile(),docLine(),this,0,si->title,TRUE,FALSE,0,TRUE,FALSE);
     //stringToSearchIndex(getOutputFileBase(),
     //                    theTranslator->trPage(TRUE,TRUE)+" "+si->title,
     //                    si->title);
@@ -134,28 +180,32 @@ void PageDef::writeDocumentation(OutputList &ol)
   ol.popGeneratorState();
   //2.}
 
-  writePageDocumentation(ol);
+  if (m_showToc && hasSections())
+  {
+    writeToc(ol);
+  }
 
-  ol.popGeneratorState();
-  //1.}
+  writePageDocumentation(ol);
 
   if (generateTreeView && getOuterScope()!=Doxygen::globalScope && !Config_getBool("DISABLE_INDEX"))
   {
     ol.endContents();
-    getOuterScope()->writeNavigationPath(ol);
-    endFile(ol,TRUE);
+    endFileWithNavPath(getOuterScope(),ol);
   }
   else
   {
     endFile(ol);
   }
 
+  ol.popGeneratorState();
+  //1.}
+
   if (!Config_getString("GENERATE_TAGFILE").isEmpty())
   {
-    bool found=FALSE;
+    bool found = name()=="citelist";
     QDictIterator<RefList> rli(*Doxygen::xrefLists);
     RefList *rl;
-    for (rli.toFirst();(rl=rli.current());++rli)
+    for (rli.toFirst();(rl=rli.current()) && !found;++rli)
     {
       if (rl->listName()==name())
       {
@@ -174,13 +224,20 @@ void PageDef::writeDocumentation(OutputList &ol)
     }
   }
 
-  Doxygen::indexList.addIndexItem(this,0,filterTitle(title()));
+  Doxygen::indexList->addIndexItem(this,0,0,filterTitle(title()));
 }
 
 void PageDef::writePageDocumentation(OutputList &ol)
 {
+
+  bool markdownEnabled = Doxygen::markdownSupport;
+  if (getLanguage()==SrcLangExt_Markdown)
+  {
+    Doxygen::markdownSupport = TRUE;
+  }
+
   ol.startTextBlock();
-  ol.parseDoc(
+  ol.generateDoc(
       docFile(),           // fileName
       docLine(),           // startLine
       this,                // context
@@ -191,6 +248,8 @@ void PageDef::writePageDocumentation(OutputList &ol)
       );
   ol.endTextBlock();
 
+  Doxygen::markdownSupport = markdownEnabled;
+
   if (hasSubPages())
   {
     // for printed documentation we write subpages as section's of the
@@ -229,14 +288,12 @@ void PageDef::writePageDocumentation(OutputList &ol)
 
 bool PageDef::visibleInIndex() const
 {
-   return // not part of a group
-          !getGroupDef() && 
-          // not an externally defined page
-          (!isReference() || Config_getBool("ALLEXTERNALS")) &&
-          // not a subpage
-          (getOuterScope()==0 || 
-           getOuterScope()->definitionType()!=Definition::TypePage
-          );
+  static bool externalPages = Config_getBool("EXTERNAL_PAGES");
+  return // not part of a group
+         !getGroupDef() && 
+         // not an externally defined page
+         (!isReference() || externalPages) 
+         ;
 }
 
 bool PageDef::documentedPage() const
@@ -257,3 +314,8 @@ void PageDef::setNestingLevel(int l)
   m_nestingLevel = l;
 }
 
+void PageDef::setShowToc(bool b)
+{
+  m_showToc = b;
+}
+
