@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * $Id:$
+ * 
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -15,6 +15,9 @@
  *
  */
 
+#ifndef PAGEDEF_H
+#define PAGEDEF_H
+
 #include "definition.h"
 #include "sortdict.h"
 
@@ -29,7 +32,7 @@ class PageDef : public Definition
    ~PageDef();
 
     // setters
-    void setFileName(const char *name) { m_fileName = name; }
+    void setFileName(const char *name);
     void setShowToc(bool b);
 
     // getters
@@ -79,9 +82,11 @@ class PageSDict : public SDict<PageDef>
   public:
     PageSDict(int size) : SDict<PageDef>(size) {}
     virtual ~PageSDict() {}
-    int compareItems(GCI i1,GCI i2)
+    int compareItems(QCollection::Item i1,QCollection::Item i2)
     {
-      return stricmp(((PageDef *)i1)->name(),((PageDef *)i2)->name());
+      return qstricmp(((PageDef *)i1)->name(),((PageDef *)i2)->name());
     }
 };
 
+#endif
+
