@@ -1,9 +1,9 @@
 /******************************************************************************
  *
- * $Id: $
+ * 
  *
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -29,7 +29,8 @@
 #include <qfileinfo.h> 
 #include "parserintf.h"
 #include "msc.h"
-
+#include "filedef.h"
+#include "config.h"
 
 //#define DBG_RTF(x) m_t << x
 #define DBG_RTF(x) do {} while(0)
@@ -130,6 +131,7 @@ void RTFDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Hash:    m_t << "#"; break;
     case DocSymbol::DoubleColon:  m_t << "::"; break;
     case DocSymbol::Percent: m_t << "%"; break;
+    case DocSymbol::Pipe:    m_t << "|"; break;
     case DocSymbol::Copy:    m_t << "(C)"; break;
     case DocSymbol::Tm:      m_t << "(TM)"; break;
     case DocSymbol::Reg:     m_t << "(R)"; break;
@@ -241,8 +243,75 @@ void RTFDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Nbsp:    m_t << "\\~ "; break;
     case DocSymbol::Aelig:   m_t << "\346"; break;
     case DocSymbol::AElig:   m_t << "\306"; break;
+    case DocSymbol::GrkGamma:        m_t << "Gamma "; break;
+    case DocSymbol::GrkDelta:        m_t << "Delta "; break;
+    case DocSymbol::GrkTheta:        m_t << "Theta "; break;
+    case DocSymbol::GrkLambda:       m_t << "Lambda "; break;
+    case DocSymbol::GrkXi:           m_t << "Xi "; break;
+    case DocSymbol::GrkPi:           m_t << "Pi "; break;
+    case DocSymbol::GrkSigma:        m_t << "Sigma "; break;
+    case DocSymbol::GrkUpsilon:      m_t << "Upsilon "; break;
+    case DocSymbol::GrkPhi:          m_t << "Phi "; break;
+    case DocSymbol::GrkPsi:          m_t << "Psi "; break;
+    case DocSymbol::GrkOmega:        m_t << "Omega "; break;
+    case DocSymbol::Grkalpha:        m_t << "alpha "; break;
+    case DocSymbol::Grkbeta:         m_t << "beta "; break;
+    case DocSymbol::Grkgamma:        m_t << "gamma "; break;
+    case DocSymbol::Grkdelta:        m_t << "delta "; break;
+    case DocSymbol::Grkepsilon:      m_t << "epsilon "; break;
+    case DocSymbol::Grkzeta:         m_t << "zeta "; break;
+    case DocSymbol::Grketa:          m_t << "eta "; break;
+    case DocSymbol::Grktheta:        m_t << "theta "; break;
+    case DocSymbol::Grkiota:         m_t << "iota "; break;
+    case DocSymbol::Grkkappa:        m_t << "kappa "; break;
+    case DocSymbol::Grklambda:       m_t << "lambda "; break;
+    case DocSymbol::Grkmu:           m_t << "mu "; break;
+    case DocSymbol::Grknu:           m_t << "nu "; break;
+    case DocSymbol::Grkxi:           m_t << "xi "; break;
+    case DocSymbol::Grkpi:           m_t << "pi "; break;
+    case DocSymbol::Grkrho:          m_t << "rho "; break;
+    case DocSymbol::Grksigma:        m_t << "sigma "; break;
+    case DocSymbol::Grktau:          m_t << "tau "; break;
+    case DocSymbol::Grkupsilon:      m_t << "upsilon "; break;
+    case DocSymbol::Grkphi:          m_t << "phi "; break;
+    case DocSymbol::Grkchi:          m_t << "chi "; break;
+    case DocSymbol::Grkpsi:          m_t << "psi "; break;
+    case DocSymbol::Grkomega:        m_t << "omega "; break;
+    case DocSymbol::Grkvarsigma:     m_t << "sigma "; break;
+    case DocSymbol::Section:         m_t << "\247"; break;
+    case DocSymbol::Degree:          m_t << "\260"; break;
+    case DocSymbol::Prime:           m_t << "'"; break;
+    case DocSymbol::DoublePrime:     m_t << "\""; break;
+    case DocSymbol::Infinity:        m_t << "inf "; break;
+    case DocSymbol::EmptySet:        m_t << "empty "; break;
+    case DocSymbol::PlusMinus:       m_t << "\261"; break;
+    case DocSymbol::Times:           m_t << "\327"; break;
+    case DocSymbol::Minus:           m_t << "-"; break;
+    case DocSymbol::CenterDot:       m_t << "."; break;
+    case DocSymbol::Partial:         m_t << "partial "; break;
+    case DocSymbol::Nabla:           m_t << "nabla "; break;
+    case DocSymbol::SquareRoot:      m_t << "sqrt "; break;
+    case DocSymbol::Perpendicular:   m_t << "perp "; break;
+    case DocSymbol::Sum:             m_t << "sum "; break;
+    case DocSymbol::Integral:        m_t << "int "; break;
+    case DocSymbol::Product:         m_t << "prod "; break;
+    case DocSymbol::Similar:         m_t << "~"; break;
+    case DocSymbol::Approx:          m_t << "approx "; break;
+    case DocSymbol::NotEqual:        m_t << "!="; break;
+    case DocSymbol::Equivalent:      m_t << "equiv "; break;
+    case DocSymbol::Proportional:    m_t << "propto "; break;
+    case DocSymbol::LessEqual:       m_t << "<="; break;
+    case DocSymbol::GreaterEqual:    m_t << ">="; break;
+    case DocSymbol::LeftArrow:       m_t << "<-"; break;
+    case DocSymbol::RightArrow:      m_t << "->"; break;
+    case DocSymbol::SetIn:           m_t << "in "; break;
+    case DocSymbol::SetNotIn:        m_t << "notin "; break;
+    case DocSymbol::LeftCeil:        m_t << "lceil "; break;
+    case DocSymbol::RightCeil:       m_t << "rceil "; break;
+    case DocSymbol::LeftFloor:       m_t << "lfloor "; break;
+    case DocSymbol::RightFloor:      m_t << "rfloor "; break;
     default:
-                             err("error: unknown symbol found\n");
+                             err("unknown symbol found\n");
   }
   m_lastIsPara=FALSE;
 }
@@ -351,6 +420,7 @@ void RTFDocVisitor::visit(DocVerbatim *s)
   {
     lang = s->language();
   }
+  SrcLangExt langExt = getLanguageFromFileName(lang);
   switch(s->type())
   {
     case DocVerbatim::Code: // fall though
@@ -358,7 +428,7 @@ void RTFDocVisitor::visit(DocVerbatim *s)
       m_t << "\\par" << endl;
       m_t << rtf_Style_Reset << getStyle("CodeExample");
       Doxygen::parserManager->getParser(lang)
-                            ->parseCode(m_ci,s->context(),s->text(),
+                            ->parseCode(m_ci,s->context(),s->text(),langExt,
                                         s->isExample(),s->exampleFile());
       //m_t << "\\par" << endl; 
       m_t << "}" << endl;
@@ -377,7 +447,8 @@ void RTFDocVisitor::visit(DocVerbatim *s)
     case DocVerbatim::HtmlOnly: 
     case DocVerbatim::LatexOnly: 
     case DocVerbatim::XmlOnly: 
-    case DocVerbatim::ManOnly: 
+    case DocVerbatim::ManOnly:
+    case DocVerbatim::DocbookOnly:
       /* nothing */
       break;
     case DocVerbatim::Dot: 
@@ -457,6 +528,7 @@ void RTFDocVisitor::visit(DocAnchor *anc)
 void RTFDocVisitor::visit(DocInclude *inc)
 {
   if (m_hide) return;
+  SrcLangExt langExt = getLanguageFromFileName(inc->extension());
   DBG_RTF("{\\comment RTFDocVisitor::visit(DocInclude)}\n");
   switch(inc->type())
   {
@@ -470,6 +542,7 @@ void RTFDocVisitor::visit(DocInclude *inc)
          Doxygen::parserManager->getParser(inc->extension())
                                ->parseCode(m_ci,inc->context(),
                                            inc->text(),
+                                           langExt,
                                            inc->isExample(),
                                            inc->exampleFile(), &fd);
          m_t << "\\par";
@@ -482,7 +555,7 @@ void RTFDocVisitor::visit(DocInclude *inc)
       m_t << rtf_Style_Reset << getStyle("CodeExample");
       Doxygen::parserManager->getParser(inc->extension())
                             ->parseCode(m_ci,inc->context(),
-                                        inc->text(),inc->isExample(),
+                                        inc->text(),langExt,inc->isExample(),
                                         inc->exampleFile());
       m_t << "\\par";
       m_t << "}" << endl;
@@ -507,6 +580,7 @@ void RTFDocVisitor::visit(DocInclude *inc)
                             ->parseCode(m_ci,
                                         inc->context(),
                                         extractBlock(inc->text(),inc->blockId()),
+                                        langExt,
                                         inc->isExample(),
                                         inc->exampleFile()
                                        );
@@ -521,6 +595,7 @@ void RTFDocVisitor::visit(DocIncOperator *op)
   //printf("DocIncOperator: type=%d first=%d, last=%d text=`%s'\n",
   //    op->type(),op->isFirst(),op->isLast(),op->text().data());
   DBG_RTF("{\\comment RTFDocVisitor::visit(DocIncOperator)}\n");
+  SrcLangExt langExt = getLanguageFromFileName(m_langExt);
   if (op->isFirst()) 
   {
     if (!m_hide)
@@ -538,7 +613,7 @@ void RTFDocVisitor::visit(DocIncOperator *op)
     if (!m_hide) 
     {
       Doxygen::parserManager->getParser(m_langExt)
-                            ->parseCode(m_ci,op->context(),op->text(),
+                            ->parseCode(m_ci,op->context(),op->text(),langExt,
                                         op->isExample(),op->exampleFile());
     }
     pushEnabled();
@@ -1601,6 +1676,16 @@ void RTFDocVisitor::visitPost(DocHtmlBlockQuote *)
   m_lastIsPara=TRUE;
 }
 
+void RTFDocVisitor::visitPre(DocVhdlFlow *)
+{
+  if (m_hide) return;
+}
+
+void RTFDocVisitor::visitPost(DocVhdlFlow *)
+{
+  if (m_hide) return;
+}
+
 
 //static char* getMultiByte(int c)
 //{
@@ -1615,7 +1700,7 @@ void RTFDocVisitor::filter(const char *str,bool verbatim)
   {
     const unsigned char *p=(const unsigned char *)str;
     unsigned char c;
-    unsigned char pc='\0';
+    //unsigned char pc='\0';
     while (*p)
     {
       //static bool MultiByte = FALSE;
@@ -1650,7 +1735,7 @@ void RTFDocVisitor::filter(const char *str,bool verbatim)
                    break;
         default:   m_t << (char)c;
       }
-      pc = c;
+      //pc = c;
     }
   }
 }
